| Title: | Open System Files, 'URLs', Anything |
|---|---|
| Description: | Cross platform solution to open files, directories or 'URLs' with their associated programs. |
| Authors: | Gábor Csárdi [aut, cre], Fathi Boudra [aut], Rex Dieter [aut], Kevin Krammer [aut], Jeremy White [aut], Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>) |
| Maintainer: | Gábor Csárdi <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.1.9000 |
| Built: | 2026-05-22 09:06:43 UTC |
| Source: | https://github.com/r-lib/xopen |
Open a file, directory or URL, using the local platforms conventions, i.e. associated applications, default programs, etc. This is usually equivalent to double-clicking on the file in the GUI.
xopen(target = NULL, app = NULL, quiet = FALSE, ...)xopen(target = NULL, app = NULL, quiet = FALSE, ...)
target |
String, the path or URL to open. |
app |
Specify the app to open |
quiet |
Whether to echo the command to the screen, before running it. |
... |
Additional arguments, not used currently. |
xopen("test.R")
xopen("https://ps.r-lib.org")
xopen(tempdir())